@@ -138,7 +138,8 @@ def identify_gap_locations(
         slider_img_url: str = None,  # 滑块图地址
         slider_img_dir: str = None,
         save_path: str = None,  # 保存文件夹
-        retain: bool = False  # 保留文件，True：保留文件，False：不保留文件
+        retain: bool = False,  # 保留文件，True：保留文件，False：不保留文件
+        proc_slider_alpha_white_max: int = None
 ):
     """
     识别缺口位置
@@ -175,7 +176,8 @@ def identify_gap_locations(
         image_dir=background_dir
     )  # 处理背景图片
     slider_proc_dir = proc_slider(
-        image_dir=slider_dir
+        image_dir=slider_dir,
+        alpha_white_max=proc_slider_alpha_white_max
     )  # 处理滑块图片
 
     # 获取尺寸
